.. how-to:
   :title: LinkML-Store How-To Guides

How-To Guides
=============

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   Use-Ibis
   Use-MongoDB
   Use-Semantic-Search
   Use-LLM-Indexing
   Query-the-Monarch-KG
   Query-Solr-using-CLI
   Use-Neo4j
   Check-Referential-Integrity
   Store-an-Ontology
   Index-Phenopackets
   Index-GO-CAMs
   Predict-Missing-Data
   Perform-RAG-Inference
   Perform-LLM-Inference
   Plot-Aggregate-Data

